pub struct TextBuffer { /* private fields */ }Expand description
A cached text buffer with layout information.
This buffer stores shaped text that can be rendered multiple times. Cache and reuse buffers when rendering the same text repeatedly.
Implementations
Sourceimpl TextBuffer
impl TextBuffer
Sourcepub fn new(font_system: &mut FontSystem) -> Self
pub fn new(font_system: &mut FontSystem) -> Self
Create a new text buffer.
Sourcepub fn set_text(
&mut self,
font_system: &mut FontSystem,
text: &Text,
scale: f32,
)
pub fn set_text( &mut self, font_system: &mut FontSystem, text: &Text, scale: f32, )
Set the text content and style.
Sourcepub fn layout(&mut self, font_system: &mut FontSystem)
pub fn layout(&mut self, font_system: &mut FontSystem)
Perform text layout if needed.